==> vtk-6.3.0-4-armv7h.pkg.tar.xz: vtk/vtkContourGrid.java <==
// java wrapper for vtkContourGrid object
//

package vtk;
import vtk.*;

public class vtkContourGrid extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfContours_4(int id0);
  public void SetNumberOfContours(int id0)
    { SetNumberOfContours_4(id0); }

  private native int GetNumberOfContours_5();
  public int GetNumberOfContours()
    { return GetNumberOfContours_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetComputeNormals_9(int id0);
  public void SetComputeNormals(int id0)
    { SetComputeNormals_9(id0); }

  private native int GetComputeNormals_10();
  public int GetComputeNormals()
    { return GetComputeNormals_10(); }

  private native void ComputeNormalsOn_11();
  public void ComputeNormalsOn()
    { ComputeNormalsOn_11(); }

  private native void ComputeNormalsOff_12();
  public void ComputeNormalsOff()
    { ComputeNormalsOff_12(); }

  private native void SetComputeGradients_13(int id0);
  public void SetComputeGradients(int id0)
    { SetComputeGradients_13(id0); }

  private native int GetComputeGradients_14();
  public int GetComputeGradients()
    { return GetComputeGradients_14(); }

  private native void ComputeGradientsOn_15();
  public void ComputeGradientsOn()
    { ComputeGradientsOn_15(); }

  private native void ComputeGradientsOff_16();
  public void ComputeGradientsOff()
    { ComputeGradientsOff_16(); }

  private native void SetComputeScalars_17(int id0);
  public void SetComputeScalars(int id0)
    { SetComputeScalars_17(id0); }

  private native int GetComputeScalars_18();
  public int GetComputeScalars()
    { return GetComputeScalars_18(); }

  private native void ComputeScalarsOn_19();
  public void ComputeScalarsOn()
    { ComputeScalarsOn_19(); }

  private native void ComputeScalarsOff_20();
  public void ComputeScalarsOff()
    { ComputeScalarsOff_20(); }

  private native void SetUseScalarTree_21(int id0);
  public void SetUseScalarTree(int id0)
    { SetUseScalarTree_21(id0); }

  private native int GetUseScalarTree_22();
  public int GetUseScalarTree()
    { return GetUseScalarTree_22(); }

  private native void UseScalarTreeOn_23();
  public void UseScalarTreeOn()
    { UseScalarTreeOn_23(); }

  private native void UseScalarTreeOff_24();
  public void UseScalarTreeOff()
    { UseScalarTreeOff_24(); }

  private native void SetLocator_25(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_25(id0); }

  private native long GetLocator_26();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_26();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetGenerateTriangles_27(int id0);
  public void SetGenerateTriangles(int id0)
    { SetGenerateTriangles_27(id0); }

  private native int GetGenerateTriangles_28();
  public int GetGenerateTriangles()
    { return GetGenerateTriangles_28(); }

  private native void GenerateTrianglesOn_29();
  public void GenerateTrianglesOn()
    { GenerateTrianglesOn_29(); }

  private native void GenerateTrianglesOff_30();
  public void GenerateTrianglesOff()
    { GenerateTrianglesOff_30(); }

  private native void CreateDefaultLocator_31();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_31(); }

  private native void SetOutputPointsPrecision_32(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_32(id0); }

  private native int GetOutputPointsPrecision_33();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_33(); }

  public vtkContourGrid() { super(); }

  public vtkContourGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkContourGrid.java <==
// java wrapper for vtkContourGrid object
//

package vtk;
import vtk.*;

public class vtkContourGrid extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfContours_4(int id0);
  public void SetNumberOfContours(int id0)
    { SetNumberOfContours_4(id0); }

  private native int GetNumberOfContours_5();
  public int GetNumberOfContours()
    { return GetNumberOfContours_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native int GetMTime_8();
  public int GetMTime()
    { return GetMTime_8(); }

  private native void SetComputeNormals_9(int id0);
  public void SetComputeNormals(int id0)
    { SetComputeNormals_9(id0); }

  private native int GetComputeNormals_10();
  public int GetComputeNormals()
    { return GetComputeNormals_10(); }

  private native void ComputeNormalsOn_11();
  public void ComputeNormalsOn()
    { ComputeNormalsOn_11(); }

  private native void ComputeNormalsOff_12();
  public void ComputeNormalsOff()
    { ComputeNormalsOff_12(); }

  private native void SetComputeGradients_13(int id0);
  public void SetComputeGradients(int id0)
    { SetComputeGradients_13(id0); }

  private native int GetComputeGradients_14();
  public int GetComputeGradients()
    { return GetComputeGradients_14(); }

  private native void ComputeGradientsOn_15();
  public void ComputeGradientsOn()
    { ComputeGradientsOn_15(); }

  private native void ComputeGradientsOff_16();
  public void ComputeGradientsOff()
    { ComputeGradientsOff_16(); }

  private native void SetComputeScalars_17(int id0);
  public void SetComputeScalars(int id0)
    { SetComputeScalars_17(id0); }

  private native int GetComputeScalars_18();
  public int GetComputeScalars()
    { return GetComputeScalars_18(); }

  private native void ComputeScalarsOn_19();
  public void ComputeScalarsOn()
    { ComputeScalarsOn_19(); }

  private native void ComputeScalarsOff_20();
  public void ComputeScalarsOff()
    { ComputeScalarsOff_20(); }

  private native void SetUseScalarTree_21(int id0);
  public void SetUseScalarTree(int id0)
    { SetUseScalarTree_21(id0); }

  private native int GetUseScalarTree_22();
  public int GetUseScalarTree()
    { return GetUseScalarTree_22(); }

  private native void UseScalarTreeOn_23();
  public void UseScalarTreeOn()
    { UseScalarTreeOn_23(); }

  private native void UseScalarTreeOff_24();
  public void UseScalarTreeOff()
    { UseScalarTreeOff_24(); }

  private native void SetScalarTree_25(vtkScalarTree id0);
  public void SetScalarTree(vtkScalarTree id0)
    { SetScalarTree_25(id0); }

  private native long GetScalarTree_26();
  public vtkScalarTree GetScalarTree() {
    long temp = GetScalarTree_26();

    if (temp == 0) return null;
    return (vtkScalarTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLocator_27(vtkIncrementalPointLocator id0);
  public void SetLocator(vtkIncrementalPointLocator id0)
    { SetLocator_27(id0); }

  private native long GetLocator_28();
  public vtkIncrementalPointLocator GetLocator() {
    long temp = GetLocator_28();

    if (temp == 0) return null;
    return (vtkIncrementalPointLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetGenerateTriangles_29(int id0);
  public void SetGenerateTriangles(int id0)
    { SetGenerateTriangles_29(id0); }

  private native int GetGenerateTriangles_30();
  public int GetGenerateTriangles()
    { return GetGenerateTriangles_30(); }

  private native void GenerateTrianglesOn_31();
  public void GenerateTrianglesOn()
    { GenerateTrianglesOn_31(); }

  private native void GenerateTrianglesOff_32();
  public void GenerateTrianglesOff()
    { GenerateTrianglesOff_32(); }

  private native void CreateDefaultLocator_33();
  public void CreateDefaultLocator()
    { CreateDefaultLocator_33(); }

  private native void SetOutputPointsPrecision_34(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_34(id0); }

  private native int GetOutputPointsPrecision_35();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_35(); }

  public vtkContourGrid() { super(); }

  public vtkContourGrid(long id) { super(id); }
  public native long   VTKInit();

}
